deepsignal
==========


Documentation
-------------

v0.1.5
-------------
normalize probs before output

v0.1.4
-------------
change the loss function to weighted_cross_entropy_with_logits,
allow training using unbalanced samples.

v0.1.3
-------------
fix the deadlock issue in multiprocessing

v0.1.2
-------------
add MANIFEST.in file

v0.1.1
-------------
3 modules (extract, call_mods, train) supported